@@ -9,6 +9,7 @@ use crate::bindgen::cargo::cargo_lock::{self, Lock};
 pub(crate) use crate::bindgen::cargo::cargo_metadata::PackageRef;
 use crate::bindgen::cargo::cargo_metadata::{self, Metadata};
 use crate::bindgen::cargo::cargo_toml;
+use crate::bindgen::config::Profile;
 use crate::bindgen::error::Error;
 use crate::bindgen::ir::Cfg;
 
@@ -39,10 +40,13 @@ impl Cargo {
         binding_crate_name: Option<&str>,
         use_cargo_lock: bool,
         clean: bool,
+        only_target_dependencies: bool,
+        existing_metadata_file: Option<&Path>,
     ) -> Result<Cargo, Error> {
         let toml_path = crate_dir.join("Cargo.toml");
-        let metadata = cargo_metadata::metadata(&toml_path)
-            .map_err(|x| Error::CargoMetadata(toml_path.to_str().unwrap().to_owned(), x))?;
+        let metadata =
+            cargo_metadata::metadata(&toml_path, existing_metadata_file, only_target_dependencies)
+                .map_err(|x| Error::CargoMetadata(toml_path.to_str().unwrap().to_owned(), x))?;
         let lock_path = lock_file
             .map(PathBuf::from)
             .unwrap_or_else(|| Path::new(&metadata.workspace_root).join("Cargo.lock"));
@@ -60,11 +64,14 @@ impl Cargo {
         };
 
         // Use the specified binding crate name or infer it from the manifest
-        let manifest = cargo_toml::manifest(&toml_path)
-            .map_err(|x| Error::CargoToml(toml_path.to_str().unwrap().to_owned(), x))?;
-
-        let binding_crate_name =
-            binding_crate_name.map_or(manifest.package.name.clone(), |x| x.to_owned());
+        let binding_crate_name = match binding_crate_name {
+            Some(s) => s.to_owned(),
+            None => {
+                let manifest = cargo_toml::manifest(&toml_path)
+                    .map_err(|x| Error::CargoToml(toml_path.to_str().unwrap().to_owned(), x))?;
+                manifest.package.name
+            }
+        };
 
         Ok(Cargo {
             manifest_path: toml_path,
@@ -135,6 +142,26 @@ impl Cargo {
             .map(|dep| {
                 let (dep_name, dep_version) = parse_dep_string(dep);
 
+                // If a version was not specified find the only package with the name of the dependency
+                let dep_version = dep_version.or_else(|| {
+                    let mut versions = self.metadata.packages.iter().filter_map(|package| {
+                        if package.name_and_version.name != dep_name {
+                            return None;
+                        }
+                        package.name_and_version.version.as_deref()
+                    });
+
+                    // If the iterator contains more items, meaning multiple versions of the same
+                    // package are present, warn! amd abort.
+                    let version = versions.next();
+                    if versions.next().is_none() {
+                        version
+                    } else {
+                        warn!("when looking for a version for package {}, multiple versions where found", dep_name);
+                        None
+                    }
+                });
+
                 // Try to find the cfgs in the Cargo.toml
                 let cfg = self
                     .metadata
@@ -209,15 +236,17 @@ impl Cargo {
         expand_all_features: bool,
         expand_default_features: bool,
         expand_features: &Option<Vec<String>>,
+        profile: Profile,
     ) -> Result<String, cargo_expand::Error> {
         cargo_expand::expand(
             &self.manifest_path,
             &package.name,
-            package.version.as_ref().map(|v| &**v),
+            package.version.as_deref(),
             self.clean,
             expand_all_features,
             expand_default_features,
             expand_features,
+            profile,
         )
     }
 }
