@@ -5,6 +5,7 @@
 use std::env;
 use std::io;
 use std::path::{Path, PathBuf};
+use std::str::FromStr;
 
 extern crate clap;
 #[macro_use]
@@ -24,28 +25,29 @@ use clap::{App, Arg, ArgMatches};
 mod bindgen;
 mod logging;
 
-use crate::bindgen::{Bindings, Builder, Cargo, Config, Error, Language, Style};
+use crate::bindgen::{Bindings, Builder, Cargo, Config, Error, Profile, Style};
 
 fn apply_config_overrides<'a>(config: &mut Config, matches: &ArgMatches<'a>) {
     // We allow specifying a language to override the config default. This is
     // used by compile-tests.
     if let Some(lang) = matches.value_of("lang") {
-        config.language = match lang {
-            "C++" => Language::Cxx,
-            "c++" => Language::Cxx,
-            "C" => Language::C,
-            "c" => Language::C,
-            _ => {
-                error!("Unknown language specified.");
+        config.language = match lang.parse() {
+            Ok(lang) => lang,
+            Err(reason) => {
+                error!("{}", reason);
                 return;
             }
-        };
+        }
     }
 
     if matches.is_present("cpp-compat") {
         config.cpp_compat = true;
     }
 
+    if matches.is_present("only-target-dependencies") {
+        config.only_target_dependencies = true;
+    }
+
     if let Some(style) = matches.value_of("style") {
         config.style = match style {
             "Both" => Style::Both,
@@ -61,6 +63,16 @@ fn apply_config_overrides<'a>(config: &mut Config, matches: &ArgMatches<'a>) {
         }
     }
 
+    if let Some(profile) = matches.value_of("profile") {
+        config.parse.expand.profile = match Profile::from_str(profile) {
+            Ok(p) => p,
+            Err(e) => {
+                error!("{}", e);
+                return;
+            }
+        }
+    }
+
     if matches.is_present("d") {
         config.parse.parse_deps = true;
     }
@@ -75,7 +87,7 @@ fn load_bindings<'a>(input: &Path, matches: &ArgMatches<'a>) -> Result<Bindings,
             None => Config::from_root_or_default(input),
         };
 
-        apply_config_overrides(&mut config, &matches);
+        apply_config_overrides(&mut config, matches);
 
         return Builder::new()
             .with_config(config)
@@ -90,6 +102,7 @@ fn load_bindings<'a>(input: &Path, matches: &ArgMatches<'a>) -> Result<Bindings,
         matches.value_of("crate"),
         true,
         matches.is_present("clean"),
+        matches.is_present("only-target-dependencies"),
         matches.value_of("metadata").map(Path::new),
     )?;
 
@@ -108,7 +121,7 @@ fn load_bindings<'a>(input: &Path, matches: &ArgMatches<'a>) -> Result<Bindings,
         }
     };
 
-    apply_config_overrides(&mut config, &matches);
+    apply_config_overrides(&mut config, matches);
 
     Builder::new()
         .with_config(config)
@@ -144,13 +157,19 @@ fn main() {
                 .long("lang")
                 .value_name("LANGUAGE")
                 .help("Specify the language to output bindings in")
-                .possible_values(&["c++", "C++", "c", "C"]),
+                .possible_values(&["c++", "C++", "c", "C", "cython", "Cython"]),
         )
         .arg(
             Arg::with_name("cpp-compat")
                 .long("cpp-compat")
                 .help("Whether to add C++ compatibility to generated C bindings")
         )
+        .arg(
+            Arg::with_name("only-target-dependencies")
+                .long("only-target-dependencies")
+                .help("Only fetch dependencies needed by the target platform. \
+                    The target platform defaults to the host platform; set TARGET to override.")
+        )
         .arg(
             Arg::with_name("style")
                 .short("s")
@@ -226,6 +245,16 @@ fn main() {
                 )
                 .required(false),
         )
+        .arg(
+            Arg::with_name("profile")
+                .long("profile")
+                .value_name("PROFILE")
+                .help(
+                    "Specify the profile to use when expanding macros. \
+                     Has no effect otherwise."
+                )
+                .possible_values(&["Debug", "debug", "Release", "release"]),
+        )
         .arg(
             Arg::with_name("quiet")
                 .short("q")
